@@ -9,6 +9,8 @@ class SentryHandler(logging.Handler):
         # Fetch the request from a threadlocal variable, if available
         request = getattr(SentryLogMiddleware.thread, 'request', None)
 
+        self.format(record)
+
         # Avoid typical config issues by overriding loggers behavior
         if record.name == 'sentry.errors':
             print >> sys.stderr, "Recursive log message sent to SentryHandler"
@@ -16,7 +18,12 @@ class SentryHandler(logging.Handler):
             return
 
         self.format(record)
-        get_client().create_from_record(record, request=request)
+        try:
+            get_client().create_from_record(record, request=request)
+        except Exception:
+            print >> sys.stderr, "Top level Sentry exception caught - failed creating log record"
+            print >> sys.stderr, record.msg
+            return
 
 try:
     import logbook
@@ -26,6 +33,8 @@ else:
     class SentryLogbookHandler(logbook.Handler):
         def emit(self, record):
             from sentry.client.models import get_client
+            
+            self.format(record)
 
             # Avoid typical config issues by overriding loggers behavior
             if record.name == 'sentry.errors':
