@@ -1,8 +1,4 @@
 import base64
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
 import datetime
 import logging
 import re
@@ -23,6 +19,7 @@ from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
 from sentry.conf import settings
 from sentry.utils import get_filters, is_float, get_signature, parse_auth_header
+from sentry.utils.compat import pickle
 from sentry.models import GroupedMessage, Message
 from sentry.plugins import GroupActionProvider
 from sentry.templatetags.sentry_helpers import with_priority
@@ -31,13 +28,22 @@ from sentry.web.reporter import ImprovedExceptionReporter
 
 uuid_re = re.compile(r'^[a-z0-9]{32}$')
 
-def render_to_response(template, context={}):
+def iter_data(obj):
+    for k, v in obj.data.iteritems():
+        if k.startswith('_') or k in ['url']:
+            continue
+        yield k, v
+
+def render_to_response(template, context={}, status=200):
     from django.shortcuts import render_to_response
 
     context.update({
         'has_search': bool(settings.SEARCH_ENGINE),
     })
-    return render_to_response(template, context)
+
+    response = render_to_response(template, context)
+    response.status_code = status
+    return response
 
 def get_search_query_set(query):
     from haystack.query import SearchQuerySet
@@ -65,9 +71,9 @@ def login_required(func):
     def wrapped(request, *args, **kwargs):
         if not settings.PUBLIC:
             if not request.user.is_authenticated():
-                return HttpResponseRedirect(reverse('sentry-login'))
+                return HttpResponseRedirect(settings.LOGIN_URL or reverse('sentry-login'))
             if not request.user.has_perm('sentry.can_view'):
-                return HttpResponseRedirect(reverse('sentry-login'))
+                return render_to_response('missing_permissions.html', status=400)
         return func(request, *args, **kwargs)
     wrapped.__doc__ = func.__doc__
     wrapped.__name__ = func.__name__
@@ -106,11 +112,6 @@ def logout(request):
 
 @login_required
 def search(request):
-    try:
-        page = int(request.GET.get('p', 1))
-    except (TypeError, ValueError):
-        page = 1
-
     query = request.GET.get('q')
     has_search = bool(settings.SEARCH_ENGINE)
 
@@ -197,15 +198,15 @@ def index(request):
 @login_required
 def ajax_handler(request):
     op = request.REQUEST.get('op')
-
-    if op == 'notification':
+    
+    def notification(request):
         return render_to_response('sentry/partial/_notification.html', request.GET)
-    elif op == 'poll':
+    
+    def poll(request):
         filters = []
         for filter_ in get_filters():
             filters.append(filter_(request))
 
-
         message_list = GroupedMessage.objects.all()
         
         sort = request.GET.get('sort')
@@ -238,8 +239,12 @@ def ajax_handler(request):
                 'count': m.times_seen,
                 'priority': p,
             }) for m, p in with_priority(message_list[0:15])]
-
-    elif op == 'resolve':
+        
+        response = HttpResponse(json.dumps(data))
+        response['Content-Type'] = 'application/json'
+        return response
+        
+    def resolve(request):
         gid = request.REQUEST.get('gid')
         if not gid:
             return HttpResponseForbidden()
@@ -262,12 +267,26 @@ def ajax_handler(request):
                 }).strip(),
                 'count': m.times_seen,
             }) for m in [group]]
+        
+        response = HttpResponse(json.dumps(data))
+        response['Content-Type'] = 'application/json'
+        return response
+    
+    def clear(request):
+        GroupedMessage.objects.all().update(status=1)
+        
+        if not request.is_ajax():
+            return HttpResponseRedirect(request.META.get('HTTP_REFERER') or reverse('sentry'))
+        
+        data = []
+        response = HttpResponse(json.dumps(data))
+        response['Content-Type'] = 'application/json'
+        return response
+        
+    if op in ['notification','poll','resolve', 'clear']:
+        return locals()[op](request)  
     else:
         return HttpResponseBadRequest()
-        
-    response = HttpResponse(json.dumps(data))
-    response['Content-Type'] = 'application/json'
-    return response
 
 @login_required
 def group(request, group_id):
@@ -297,17 +316,17 @@ def group(request, group_id):
         traceback = mark_safe('<pre>%s</pre>' % (group.traceback,))
         version_data = None
     
-    def iter_data(obj):
-        for k, v in obj.data.iteritems():
-            if k.startswith('_') or k in ['url']:
-                continue
-            yield k, v
+    else:
+        traceback = None
+        version_data = None
     
-    json_data = iter_data(obj)
-    
-    page = 'details'
-    
-    return render_to_response('sentry/group/details.html', locals())
+    return render_to_response('sentry/group/details.html', {
+        'page': 'details',
+        'group': group,
+        'json_data': iter_data(obj),
+        'traceback': traceback,
+        'version_data': version_data,
+    })
 
 @login_required
 def group_message_list(request, group_id):
@@ -315,9 +334,12 @@ def group_message_list(request, group_id):
 
     message_list = group.message_set.all().order_by('-datetime')
     
-    page = 'messages'
-    
-    return render_to_response('sentry/group/message_list.html', locals())
+    return render_to_response('sentry/group/message_list.html', {
+        'group': group,
+        'message_list': message_list,
+        'page': 'messages',
+        'request' : request
+    })
 
 @login_required
 def group_message_details(request, group_id, message_id):
@@ -336,20 +358,20 @@ def group_message_details(request, group_id, message_id):
     
         reporter = ImprovedExceptionReporter(message.request, exc_type, exc_value, frames, message.data['__sentry__'].get('template'))
         traceback = mark_safe(reporter.get_traceback_html())
+
     elif group.traceback:
         traceback = mark_safe('<pre>%s</pre>' % (group.traceback,))
+
+    else:
+        traceback = None
     
-    def iter_data(obj):
-        for k, v in obj.data.iteritems():
-            if k.startswith('_') or k in ['url']:
-                continue
-            yield k, v
-    
-    json_data = iter_data(message)
-    
-    page = 'messages'
-    
-    return render_to_response('sentry/group/message.html', locals())
+    return render_to_response('sentry/group/message.html', {
+        'page': 'messages',
+        'group': group,
+        'message': message,
+        'json_data': iter_data(message),
+        'traceback': traceback,
+    })
 
 @csrf_exempt
 def store(request):
